location_prologue = {
    'af': 'Weer verslag vir:',
    'ar': 'تقرير حالة ألطقس',
    'az': 'Hava proqnozu:',
    'bg': 'Прогноза за времето в:',
    'ca': 'Informe del temps per a:',
    'da': 'Vejret i:',
    'de': 'Wetterbericht für:',
    'el': 'Πρόγνωση καιρού για:',
    'es': 'El tiempo en:',
    'eu': 'Eguraldia:',
    'fa': 'اوه و بآ تیعضو شرازگ',
    'fi': 'Säätiedotus:',
    'fr': 'Prévisions météo pour:',
    'he': ':ריוואה גזמ תיזחת',
    'hi': 'मौसम की जानकारी',
    'hr': 'Vremenska prognoza za:',
    'hu': 'Időjárás előrejelzés:',
    'id': 'Prakiraan cuaca:',
    'it': 'Previsioni meteo:',
    'ja': '天気予報：',
    'en': 'Weather forecast for:',
    'lt': 'Orų prognozė:',
    'mk': 'Прогноза за времето во:',
    'nl': 'Weerbericht voor:',
    'pl': 'Pogoda w:',
    'pt': 'Previsão do tempo para:',
    'ro': 'Prognoza meteo pentru:',
    'ru': 'Прогноз погоды:',
    'sk': 'Predpoveď počasia pre:',
    'sl': 'Vremenska napoved za',
    'sr': 'Временска прогноза за:',
    'sv': 'Väderleksprognos för:',
    'th': 'รายงานสภาพอากาศ:',
    'tr': 'Hava beklentisi:',
    'uk': 'Прогноз погоди для:',
    'vi': 'Báo cáo thời tiết:',
    'zu': 'Isimo sezulu:'
}

parts_of_day = {
    'af': ('Oggend', 'Middag', 'Vroegaand', 'Laatnag'),
    'ar': ('ﺎﻠﻠﻴﻟ', 'ﺎﻠﻤﺳﺍﺀ', 'ﺎﻠﻈﻫﺭ', 'ﺎﻠﺼﺑﺎﺣ'),
    'az': ('Səhər', 'Gün', 'Axşam', 'Gecə'),
    'bg': ('Сутрин', 'Обяд', 'Вечер', 'Нощ'),
    'ca': ('Matí', 'Dia', 'Tarda', 'Nit'),
    'da': ('Morgen', 'Middag', 'Aften', 'Nat'),
    'de': ('Früh', 'Mittag', 'Abend', 'Nacht'),
    'el': ('Πρωί', 'Μεσημέρι', 'Απόγευμα', 'Βράδυ'),
    'en': ('Morning', 'Noon', 'Evening', 'Night'),
    'es': ('Mañana', 'Mediodía', 'Tarde', 'Noche'),
    'eu': ('Goiza', 'Eguerdia', 'Arratsaldea', 'Gaua'),
    'fa': ('حبص', 'رهظ', 'رصع', 'بش'),
    'fi': ('Aamu', 'Keskipäivä', 'Ilta', 'Yö'),
    'fr': ('Matin', 'Après-midi', 'Soir', 'Nuit'),
    'he': ('רקוב', 'םוֹיְ', 'ברֶעֶ', 'הלָיְלַ'),
    'hi': ('प्रातःकाल', 'दोपहर', 'सायंकाल', 'रात'),
    'hr': ('Jutro', 'Dan', 'Večer', 'Noć'),
    'hu': ('Reggel', 'Dél', 'Este', 'Éjszaka'),
    'id': ('Pagi', 'Hari', 'Petang', 'Malam'),
    'it': ('Mattina', 'Pomeriggio', 'Sera', 'Notte'),
    'ja': ('朝', '昼', '夕', '夜'),
    'lt': ('Rytas', 'Diena', 'Vakaras', 'Naktis'),
    'mk': ('Утро', 'Пладне', 'Вечер', 'Ноќ'),
    'nl': ("'s Ochtends", "'s Middags", "'s Avonds", "'s Nachts"),
    'pl': ('Ranek', 'Dzień', 'Wieczór', 'Noc'),
    'pt': ('Manhã', 'Meio-dia', 'Tarde', 'Noite'),
    'ro': ('Dimineaţă', 'Amiază', 'Seară', 'Noapte'),
    'ru': ('Утро', 'День', 'Вечер', 'Ночь'),
    'sk': ('Ráno', 'Cez deň', 'Večer', 'V noci'),
    'sl': ('Jutro', 'Dan', 'Večer', 'Noč'),
    'sr': ('Јутро', 'Подне', 'Вече', 'Ноћ'),
    'sv': ('Morgon', 'Eftermiddag', 'Kväll', 'Natt'),
    'th': ('เช้า', 'วัน', 'เย็น', 'คืน'),
    'tr': ('Sabah', 'Öğle', 'Akşam', 'Gece'),
    'uk': ('Ранок', 'День', 'Вечір', 'Ніч'),
    'vi': ('Sáng', 'Trưa', 'Chiều', 'Tối'),
    'zu': ('Morning', 'Noon', 'Evening', 'Night')
}

lang_names = {
    'af': {'name': 'Afrikaans', 'dir': 1, 'native': 'Afrikaans'},
    'ar': {'name': 'Arabic', 'dir': 0, 'native': 'العربية'},
    'az': {'name': 'Azerbaijani', 'dir': 1, 'native': 'Azərbaycanca / آذربايجان'},
    'bg': {'name': 'Bulgarian', 'dir': 1, 'native': 'Български'},
    'ca': {'name': 'Catalan', 'dir': 1, 'native': 'Català'},
    'da': {'name': 'Danish', 'dir': 1, 'native': 'Dansk'},
    'de': {'name': 'German', 'dir': 1, 'native': 'Deutsch'},
    'el': {'name': 'Greek', 'dir': 1, 'native': 'Ελληνικά'},
    'en': {'name': 'English', 'dir': 1, 'native': 'English'},
    'es': {'name': 'Spanish', 'dir': 1, 'native': 'Español'},
    'eu': {'name': 'Basque', 'dir': 1, 'native': 'Euskara'},
    'fa': {'name': 'Persian', 'dir': 0, 'native': 'فارسی'},
    'fi': {'name': 'Finnish', 'dir': 1, 'native': 'Suomi'},
    'fr': {'name': 'French', 'dir': 1, 'native': 'Français'},
    'he': {'name': 'Hebrew', 'dir': 0, 'native': 'עברית'},
    'hi': {'name': 'Hindi', 'dir': 1, 'native': 'हिन्दी'},
    'hr': {'name': 'Croatian', 'dir': 1, 'native': 'Hrvatski'},
    'hu': {'name': 'Hungarian', 'dir': 1, 'native': 'Magyar'},
    'id': {'name': 'Indonesian', 'dir': 1, 'native': 'Bahasa Indonesia'},
    'it': {'name': 'Italian', 'dir': 1, 'native': 'Italiano'},
    'ja': {'name': 'Japanese', 'dir': 1, 'native': '日本語'},
    'lt': {'name': 'Lithuanian', 'dir': 1, 'native': 'Lietuvių'},
    'mk': {'name': 'Macedonian', 'dir': 1, 'native': 'Македонски'},
    'nl': {'name': 'Dutch', 'dir': 1, 'native': 'Nederlands'},
    'pl': {'name': 'Polish', 'dir': 1, 'native': 'Polski'},
    'pt': {'name': 'Portuguese', 'dir': 1, 'native': 'Português'},
    'ro': {'name': 'Romanian', 'dir': 1, 'native': 'Română'},
    'ru': {'name': 'Russian', 'dir': 1, 'native': 'Русский'},
    'sk': {'name': 'Slovak', 'dir': 1, 'native': 'Slovenčina'},
    'sl': {'name': 'Slovenian', 'dir': 1, 'native': 'Slovenščina'},
    'sr': {'name': 'Serbian', 'dir': 1, 'native': 'Српски'},
    'sv': {'name': 'Swedish', 'dir': 1, 'native': 'Svenska'},
    'th': {'name': 'Thai', 'dir': 1, 'native': 'ไทย / Phasa Thai'},
    'tr': {'name': 'Turkish', 'dir': 1, 'native': 'Türkçe'},
    'uk': {'name': 'Ukrainian', 'dir': 1, 'native': 'Українська'},
    'vi': {'name': 'Vietnamese', 'dir': 1, 'native': 'Việtnam'},
    'zu': {'name': 'Zulu', 'dir': 1, 'native': 'isiZulu'}
}

lang_codes = {
    'afrikaans': 'af',
    'arabic': 'ar',
    'العربية': 'ar',
    'azerbaijani': 'az',
    'azərbaycanca': 'az',
    'آذربايجان': 'az',
    'bulgarian': 'bg',
    'български': 'bg',
    'catalan': 'ca',
    'català': 'ca',
    'danish': 'da',
    'dansk': 'da',
    'german': 'de',
    'deutsch': 'de',
    'greek': 'el',
    'ελληνικά': 'el',
    'english': 'en',
    'spanish': 'es',
    'español': 'es',
    'basque': 'eu',
    'euskara': 'eu',
    'persian': 'fa',
    'فارسی': 'fa',
    'finnish': 'fi',
    'suomi': 'fi',
    'french': 'fr',
    'français': 'fr',
    'hebrew': 'he',
    'עברית': 'he',
    'hindi': 'hi',
    'हिन्दी': 'hi',
    'croatian': 'hr',
    'hrvatski': 'hr',
    'hungarian': 'hu',
    'magyar': 'hu',
    'indonesian': 'id',
    'bahasa indonesia': 'id',
    'italian': 'it',
    'italiano': 'it',
    'japanese': 'ja',
    '日本語': 'ja',
    'lithuanian': 'lt',
    'lietuvių': 'lt',
    'macedonian': 'mk',
    'македонски': 'mk',
    'dutch': 'nl',
    'nederlands': 'nl',
    'polish': 'pl',
    'polski': 'pl',
    'portuguese': 'pt',
    'português': 'pt',
    'romanian': 'ro',
    'română': 'ro',
    'russian': 'ru',
    'русский': 'ru',
    'slovak': 'sk',
    'slovenčina': 'sk',
    'slovenian': 'sl',
    'slovenščina': 'sl',
    'serbian': 'sr',
    'српски': 'sr',
    'swedish': 'sv',
    'svenska': 'sv',
    'thai': 'th',
    'ไทย': 'th',
    'phasa thai': 'th',
    'turkish': 'tr',
    'türkçe': 'tr',
    'ukrainian': 'uk',
    'українська': 'uk',
    'vietnamese': 'vi',
    'việtnam': 'vi',
    'zulu': 'zu',
    'isizulu': 'zu'
}

location = {
    'en': 'Location',
    'af': 'Ligging',
    'ar': 'الموقع',
    'bg': 'Местоположение',
    'ca': 'Ubicació',
    'de': 'Ort',
    'da': 'Lokation',
    'el': 'Τοποθεσία',
    'es': 'Ubicación',
    'eu': 'Kokaena',
    'fa': 'مکان',
    'fi': 'Tuntematon sijainti',
    'fr': 'Emplacement',
    'hi': 'स्थान',
    'hu': 'Lokáció',
    'id': 'Lokasi',
    'it': 'Località',
    'ja': '位置情報',
    'lt': 'Vietovė',
    'mk': 'Локација',
    'nl': 'Locatie',
    'pl': 'Lokalizacja',
    'pt': 'Localização',
    'ro': 'Localitate',
    'ru': 'Местоположение',
    'sk': 'Poloha',
    'sl': 'Lokacijo',
    'sr': 'Локација',
    'sv': 'Plats',
    'tr': 'Konum',
    'th': 'ตำแหน่ง',
    'uk': 'Місцезнаходження',
    'vi': 'Địa điểm'
}

unknown_location = {
    'en': 'Unknown location',
    'af': 'Onbekende ligging',
    'ar': 'موقع غير معروف',
    'bg': 'Неизвестно местоположение',
    'ca': 'Ubicació desconeguda',
    'de': 'Unbekannter Ort',
    'da': 'Ukendt lokation',
    'el': 'Άνγωστη τοποθεσία',
    'es': 'Ubicación desconocida',
    'eu': 'Kokapen ezezaguna',
    'fa': 'مکان نامعلوم',
    'fi': 'Tuntematon sijainti',
    'fr': 'Emplacement inconnu',
    'hi': 'अज्ञात स्थान',
    'hu': 'Ismeretlen lokáció',
    'id': 'Lokasi tidak diketahui',
    'it': 'Località sconosciuta',
    'ja': '未知の場所です',
    'lt': 'Nežinoma vietovė',
    'mk': 'Непозната локација',
    'nl': 'Onbekende locatie',
    'pl': 'Nieznana lokalizacja',
    'pt': 'Localização desconhecida',
    'ro': 'Localitate necunoscută',
    'ru': 'Неизвестное местоположение',
    'sk': 'Neznáma poloha',
    'sl': 'Neznano lokacijo',
    'sr': 'Непозната локација',
    'sv': 'Okänd plats',
    'tr': 'Bilinmeyen konum',
    'th': 'ไม่สามารถระบุตำแหน่งได้',
    'uk': 'Невідоме місце',
    'vi': 'Địa điểm không xác định'
}
